summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycalendar.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneycalendar.h')
-rw-r--r--kmymoney2/widgets/kmymoneycalendar.h67
1 files changed, 34 insertions, 33 deletions
diff --git a/kmymoney2/widgets/kmymoneycalendar.h b/kmymoney2/widgets/kmymoneycalendar.h
index b0e2328..25ce79f 100644
--- a/kmymoney2/widgets/kmymoneycalendar.h
+++ b/kmymoney2/widgets/kmymoneycalendar.h
@@ -49,8 +49,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qframe.h>
-#include <qdatetime.h>
+#include <tqframe.h>
+#include <tqdatetime.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -61,11 +61,11 @@
// Project Includes
#include "kmymoneydatetbl.h"
-class QLineEdit;
-class QToolButton;
+class TQLineEdit;
+class TQToolButton;
class KDateValidator;
class kMyMoneyDateTbl;
-class QPushButton;
+class TQPushButton;
/**
* A representation of a calendar.
@@ -73,15 +73,16 @@ class QPushButton;
* @author Michael Edwardes 2003
*
**/
-class kMyMoneyCalendar : public QFrame {
+class kMyMoneyCalendar : public TQFrame {
Q_OBJECT
+ TQ_OBJECT
public:
public:
/**
* Standard constructor.
**/
- kMyMoneyCalendar(QWidget *parent=0, const char *name=0);
+ kMyMoneyCalendar(TQWidget *tqparent=0, const char *name=0);
/**
* Standard destructor.
@@ -104,7 +105,7 @@ public:
* size hint, try adding 28 to each of the reported numbers of
* pixels.
**/
- QSize sizeHint() const;
+ TQSize tqsizeHint() const;
/**
* Sets the date.
@@ -112,18 +113,18 @@ public:
* @returns @p false and does not change anything
* if the date given is invalid.
**/
- bool setDate(const QDate&);
+ bool setDate(const TQDate&);
/**
* Returns the selected date.
* @deprecated
**/
- const QDate& getDate() const;
+ const TQDate& getDate() const;
/**
* @returns the selected date.
*/
- const QDate &date() const;
+ const TQDate &date() const;
/**
* Enables or disables the widget.
@@ -143,7 +144,7 @@ public:
/**
* By calling this method with @p enable = true, KDatePicker will show
* a little close-button in the upper button-row. Clicking the
- * close-button will cause the KDatePicker's topLevelWidget()'s close()
+ * close-button will cause the KDatePicker's tqtopLevelWidget()'s close()
* method being called. This is mostly useful for toplevel datepickers
* without a window manager decoration.
* @see #hasCloseButton
@@ -163,41 +164,41 @@ public:
**/
virtual void setDateTable(kMyMoneyDateTbl *tbl) = 0;
- void setUserButton1(bool enable, QPushButton* pb);
- void setUserButton2(bool enable, QPushButton* pb);
+ void setUserButton1(bool enable, TQPushButton* pb);
+ void setUserButton2(bool enable, TQPushButton* pb);
protected:
- /// to catch move keyEvents when QLineEdit has keyFocus
- virtual bool eventFilter(QObject *o, QEvent *e );
+ /// to catch move keyEvents when TQLineEdit has keyFocus
+ virtual bool eventFilter(TQObject *o, TQEvent *e );
/// the resize event
- virtual void resizeEvent(QResizeEvent*);
+ virtual void resizeEvent(TQResizeEvent*);
/// the style control button
- QPushButton *styleControl;
+ TQPushButton *styleControl;
/// the year forward button
- QToolButton *yearForward;
+ TQToolButton *yearForward;
/// the year backward button
- QToolButton *yearBackward;
+ TQToolButton *yearBackward;
/// the month forward button
- QToolButton *monthForward;
+ TQToolButton *monthForward;
/// the month backward button
- QToolButton *monthBackward;
+ TQToolButton *monthBackward;
/// the button for selecting the month directly
- QToolButton *selectMonth;
+ TQToolButton *selectMonth;
/// the button for selecting the year directly
- QToolButton *selectYear;
+ TQToolButton *selectYear;
/// the line edit to enter the date directly
- QLineEdit *line;
+ TQLineEdit *line;
/// the validator for the line edit:
KDateValidator *val;
/// the date table
kMyMoneyDateTbl *table;
/// the size calculated during resize events
- // QSize sizehint;
+ // TQSize sizehint;
/// the widest month string in pixels:
- QSize maxMonthRect;
+ TQSize maxMonthRect;
protected slots:
- void dateChangedSlot(QDate);
+ void dateChangedSlot(TQDate);
void tableClickedSlot();
void monthForwardClicked();
void monthBackwardClicked();
@@ -220,19 +221,19 @@ signals:
* selected.
* @see dateSelected
*/
- void dateChanged(QDate);
+ void dateChanged(TQDate);
/** This signal is emitted each time a day has been selected by
* clicking on the table (hitting a day in the current month). It
* has the same meaning as dateSelected() in older versions of
* KDatePicker.
*/
- void dateSelected(QDate);
+ void dateSelected(TQDate);
/** This signal is emitted when enter is pressed and a VALID date
* has been entered before into the line edit. Connect to both
* dateEntered() and dateSelected() to receive all events where the
* user really enters a date.
*/
- void dateEntered(QDate);
+ void dateEntered(TQDate);
/** This signal is emitted when the day has been selected by
* clicking on it in the table.
*/
@@ -244,13 +245,13 @@ private:
protected:
virtual void virtual_hook( int id, void* data );
- void init( const QDate &dt );
+ void init( const TQDate &dt );
private:
class kMyMoneyCalendarPrivate;
kMyMoneyCalendarPrivate* const d;
// calculate ISO 8601 week number
- int weekOfYear(QDate);
+ int weekOfYear(TQDate);
#if KDE_IS_VERSION(3,2,0)
#define MONTH_NAME(a,b,c) KGlobal::locale()->calendar()->monthName(a,b,c)